==> snipe-it-6.3.0.zip: snipe-it-6.3.0/resources/lang/tr-TR/localizations.php <==
<?php

return [

    'select_language' => 'Bir dil seçin',
    'languages' => [
        'en-US'=> 'İngilizce, US',
        'en-GB'=> 'İngilizce, UK',
        'am-ET' => 'Amharic',
        'af-ZA'=> 'Akrika dili',
        'ar-SA'=> 'Arapça',
        'bg-BG'=> 'Bulgarca',
        'zh-CN'=> 'Basitleştirilmiş Çince',
        'zh-TW'=> 'Geleneksel Çince',
        'ca-ES' => 'Catalan',
        'hr-HR'=> 'Hırvatça',
        'cs-CZ'=> 'Çekçe',
        'da-DK'=> 'Danca',
        'nl-NL'=> 'Hollanda Felemenkçe',
        'en-ID'=> 'İngilizce, Endonezya',
        'et-EE'=> 'Estonya Estçe',
        'fil-PH'=> 'Filipince',
        'fi-FI'=> 'Fince',
        'fr-FR'=> 'Fransızca',
        'de-DE'=> 'Almanca',
        'de-if'=> 'Almanca (Gayri Resmi)',
        'el-GR'=> 'Yunanca',
        'he-IL'=> 'İbranice',
        'hu-HU'=> 'Macarca',
        'is-IS' => 'İzlandaca',
        'id-ID'=> 'Endonezyaca',
        'ga-IE'=> 'İrlandaca',
        'it-IT'=> 'İtalyanca',
        'ja-JP'=> 'Japonca',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Korece',
        'lt-LT'=>'Litvanyaca',
        'lv-LV'=> 'Letonca',
        'mk-MK'=> 'Makedonca',
        'ms-MY'=> 'Malayca',
        'mi-NZ'=> 'Maori Dili',
        'mn-MN'=> 'Moğolca',
        'no-NO'=> 'Norveç dili',
        'fa-IR'=> 'Farsça',
        'pl-PL'=> 'Polonyaca',
        'pt-PT'=> 'Portekizce',
        'pt-BR'=> 'Brezilya Portekizcesi',
        'ro-RO'=> 'Rumence',
        'ru-RU'=> 'Rusça',
        'sr-CS' => 'Sırpça (Latin)',
        'sk-SK'=> 'Slovak',
        'sl-SI'=> 'Slovakça',
        'es-ES'=> 'İspanyolca',
        'es-CO'=> 'İspanyolca, Kolombiya',
        'es-MX'=> 'İspanyolca, Meksika',
        'es-VE'=> 'İspanyolca, Venezuela',
        'sv-SE'=> 'İsveç dili',
        'tl-PH'=> 'Tagalogca',
        'ta-IN'=> 'Tamilce',
        'th-TH'=> 'Tayland Dili',
        'tr-TR'=> 'Türkçe',
        'uk-UA'=> 'Ukraynaca',
        'vi-VN'=> 'Vietnamca',
        'cy-GB'=> 'Galce',
        'zu-ZA'=> 'Zuluca',
    ],

    'select_country' => 'Ülke seçin',
    
    'countries' => [
        'AC'=>'Ascension Adası',
        'AD'=>'Andorra',
        'AE'=>'Birleşik Arap Emirlikleri',
        'AF'=>'Afganistan',
        'AG'=>'Antigua ve Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Arnavutluk',
        'AM'=>'Ermenistan',
        'AN'=>'Hollanda Antilleri',
        'AO'=>'Angola',
        'AQ'=>'Antarktika',
        'AR'=>'Arjantin',
        'AS'=>'Amerikan Samoası',
        'AT'=>'Avusturya',
        'AU'=>'Avustralya',
        'AW'=>'Aruba',
        'AX'=>'Aland',
        'AZ'=>'Azerbaycan',
        'BA'=>'Bosna Hersek',
        'BB'=>'Barbados',
        'BE'=>'Belçika',
        'BD'=>'Bangladeş',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaristan',
        'BH'=>'Bahreyn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Sultanlığı',
        'BO'=>'Bolivya',
        'BR'=>'Brezilya',
        'BS'=>'Bahamalar',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Adası',
        'BW'=>'Botsvana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Cocos (Keeling) Adaları',
        'CD'=>'Kongo Demokratik Cumhuriyeti',
        'CF'=>'Orta Afrika Cumhuriyeti',
        'CG'=>'Kongo Cunhuriyeti',
        'CH'=>'İsviçre',
        'CI'=>'Fildişi Sahili',
        'CK'=>'Cook Adaları',
        'CL'=>'Şili',
        'CM'=>'Kamerun',
        'CN'=>'Çin',
        'CO'=>'Kolombiya',
        'CR'=>'Kosta Rika',
        'CU'=>'Küba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Adası',
        'CY'=>'Kıbrıs',
        'CZ'=>'Çek Cumhuriyeti',
        'DE'=>'Almanya',
        'DJ'=>'Cibuti',
        'DK'=>'Danimarka',
        'DM'=>'Dominik',
        'DO'=>'Dominik Cumhuriyeti',
        'DZ'=>'Cezayir',
        'EC'=>'Ekvador',
        'EE'=>'Estonya',
        'EG'=>'Mısır',
        'ER'=>'Eritre',
        'ES'=>'İspanya',
        'ET'=>'Etiyopya',
        'EU'=>'Avrupa Birliği',
        'FI'=>'Finlandiya',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Adaları (Malvinalar)',
        'FM'=>'Mikronezya Federal Devletleri',
        'FO'=>'Faroe Adaları',
        'FR'=>'Fransa',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gürcistan',
        'GF'=>'Fransız Guyanası',
        'GG'=>'Guernsey',
        'GH'=>'Gana',
        'GI'=>'Cebelitarık',
        'GL'=>'Grönland',
        'GM'=>'Gambiya',
        'GN'=>'Gine',
        'GP'=>'Guadeloup',
        'GQ'=>'Ekvator Ginesi',
        'GR'=>'Yunanistan',
        'GS'=>'Güney Georgia ve Güney Sandviç Adaları',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Gine-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard ve Mc Donald Adaları',
        'HN'=>'Honduras',
        'HR'=>'Hırvatistan (yerel adı: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Macaristan',
        'ID'=>'Endonezya',
        'IE'=>'İrlanda',
        'IL'=>'İsrail',
        'IM'=>'Man Adası',
        'IN'=>'Hindistan',
        'IO'=>'İngiliz Hint Okyanusu Bölgesi',
        'IQ'=>'Irak',
        'IR'=>'İran İslam Cumhuriyeti',
        'IS'=>'İzlanda',
        'IT'=>'İtalya',
        'JE'=>'Jersey',
        'JM'=>'Jamaika',
        'JO'=>'Ürdün',
        'JP'=>'Japonya',
        'KE'=>'Kenya',
        'KG'=>'Kırgızistan',
        'KH'=>'Kamboçya',
        'KI'=>'Kiribati',
        'KM'=>'Komor Adaları',
        'KN'=>'Saint Kitts ve Nevis',
        'KR'=>'Kore Cumhuriyeti',
        'KW'=>'Kuveyt',
        'KY'=>'Cayman Adaları',
        'KZ'=>'Kazakistan',
        'LA'=>'Lao Demokratik Halk Cumhuriyeti',
        'LB'=>'Lübnan',
        'LC'=>'Saint Lucia',
        'LI'=>'Lihtenştayn',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberya',
        'LS'=>'Lesoto',
        'LT'=>'Litvanya',
        'LU'=>'Lüksemburg',
        'LV'=>'Letonya',
        'LY'=>'Libya Arap Cemahiriyesi',
        'MA'=>'Fas',
        'MC'=>'Monako',
        'MD'=>'Moldova Cumhuriyeti',
        'ME'=>'Karadağ',
        'MG'=>'Madagaskar',
        'MH'=>'Marshall Adaları',
        'MK'=>'Makedonya, Eski Yugoslav Cumhuriyeti',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Moğolistan',
        'MO'=>'Makao',
        'MP'=>'Kuzey Mariana Adaları',
        'MQ'=>'Martinik',
        'MR'=>'Moritanya',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldivler',
        'MW'=>'Malavi',
        'MX'=>'Meksika',
        'MY'=>'Malezya',
        'MZ'=>'Mozambik',
        'NA'=>'Namibya',
        'NC'=>'Yeni Kaledonya',
        'NE'=>'Nijer',
        'NF'=>'Norfolk Adası',
        'NG'=>'Nijerya',
        'NI'=>'Nikaragua',
        'NL'=>'Hollanda',
        'NO'=>'Norveç',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Yeni Zelanda',
        'OM'=>'Umman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Fransız Polinezyası',
        'PG'=>'Papua Yeni Gine',
        'PH'=>'Filipin Cumhuriyeti',
        'PK'=>'Pakistan',
        'PL'=>'Polonya',
        'PM'=>'Saint Pierre ve Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Porto Riko',
        'PS'=>'Filistin',
        'PT'=>'Portekiz',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Katar',
        'RE'=>'Reunion adası',
        'RO'=>'Romanya',
        'RS'=>'Sırbistan',
        'RU'=>'Rusya Federasyonu',
        'RW'=>'Ruanda',
        'SA'=>'Suudi Arabistan',
        'UK'=>'İskoçya',
        'SB'=>'Solomon Adaları',
        'SC'=>'Seyşel Adaları',
        'SS'=>'Güney Sudan',
        'SD'=>'Sudan',
        'SE'=>'İsveç',
        'SG'=>'Singapur',
        'SH'=>'Saint Helena',
        'SI'=>'Slovenya',
        'SJ'=>'Svalbard ve Jan Mayen',
        'SK'=>'Slovakya (Slovak Cumhuriyeti)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somali',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome ve Principe',
        'SU'=>'Sovyetler Birliği',
        'SV'=>'El Salvador',
        'SY'=>'Suriye Arap Cumhuriyeti',
        'SZ'=>'Svaziland',
        'TC'=>'Turks ve Caicos Adaları',
        'TD'=>'Çad',
        'TF'=>'Fransız Güney Toprakları',
        'TG'=>'Togo',
        'TH'=>'Tayland',
        'TJ'=>'Tacikistan',
        'TK'=>'Tokelau',
        'TI'=>'Doğu Timor',
        'TM'=>'Türkmenistan',
        'TN'=>'Tunus',
        'TO'=>'Tonga',
        'TP'=>'Doğu Timor (eski kod)',
        'TR'=>'Türkiye',
        'TT'=>'Trinidad ve Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tayvan',
        'TZ'=>'Birleşik Tanzaya Cumhuriyeti',
        'UA'=>'Ukrayna',
        'UG'=>'Uganda',
        'UK'=>'Birleşik Krallık',
        'US'=>'Amerika Birleşik Devletleri',
        'UM'=>'Amerika Birleşik Devletleri Küçük Dış Adaları',
        'UY'=>'Uruguay',
        'UZ'=>'Özbekistan',
        'VA'=>'Vatikan Şehir Devleti (Vatikan)',
        'VC'=>'Saint Vincent ve Grenadinler',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Adaları (Britanya)',
        'VI'=>'Virgin Adaları (Abd)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis ve Futuna Adaları',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Güney Afrika',
        'ZM'=>'Zambiya',
        'ZW'=>'Zimbabve',
    ],
];

==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/tr-TR/localizations.php <==
<?php

return [

    'select_language' => 'Bir dil seçin',
    'languages' => [
        'en-US'=> 'İngilizce, US',
        'en-GB'=> 'İngilizce, UK',
        'am-ET' => 'Amharca',
        'af-ZA'=> 'Akrika dili',
        'ar-SA'=> 'Arapça',
        'bg-BG'=> 'Bulgarca',
        'zh-CN'=> 'Basitleştirilmiş Çince',
        'zh-TW'=> 'Geleneksel Çince',
        'ca-ES' => 'Katalanca',
        'hr-HR'=> 'Hırvatça',
        'cs-CZ'=> 'Çekçe',
        'da-DK'=> 'Danca',
        'nl-NL'=> 'Hollanda Felemenkçe',
        'en-ID'=> 'İngilizce, Endonezya',
        'et-EE'=> 'Estonya Estçe',
        'fil-PH'=> 'Filipince',
        'fi-FI'=> 'Fince',
        'fr-FR'=> 'Fransızca',
        'de-DE'=> 'Almanca',
        'de-if'=> 'Almanca (Gayri Resmi)',
        'el-GR'=> 'Yunanca',
        'he-IL'=> 'İbranice',
        'hu-HU'=> 'Macarca',
        'is-IS' => 'İzlandaca',
        'id-ID'=> 'Endonezyaca',
        'ga-IE'=> 'İrlandaca',
        'it-IT'=> 'İtalyanca',
        'ja-JP'=> 'Japonca',
        'km-KH'=>'Khmer',
        'ko-KR'=> 'Korece',
        'lt-LT'=>'Litvanyaca',
        'lv-LV'=> 'Letonca',
        'mk-MK'=> 'Makedonca',
        'ms-MY'=> 'Malayca',
        'mi-NZ'=> 'Maori Dili',
        'mn-MN'=> 'Moğolca',
        'no-NO'=> 'Norveç dili',
        'fa-IR'=> 'Farsça',
        'pl-PL'=> 'Polonyaca',
        'pt-PT'=> 'Portekizce',
        'pt-BR'=> 'Brezilya Portekizcesi',
        'ro-RO'=> 'Rumence',
        'ru-RU'=> 'Rusça',
        'sr-CS' => 'Sırpça (Latin)',
        'sk-SK'=> 'Slovakça',
        'sl-SI'=> 'Slovakça',
        'so-SO'=> 'Somali',
        'es-ES'=> 'İspanyolca',
        'es-CO'=> 'İspanyolca, Kolombiya',
        'es-MX'=> 'İspanyolca, Meksika',
        'es-VE'=> 'İspanyolca, Venezuela',
        'sv-SE'=> 'İsveç dili',
        'tl-PH'=> 'Tagalogca',
        'ta-IN'=> 'Tamilce',
        'th-TH'=> 'Tayland Dili',
        'tr-TR'=> 'Türkçe',
        'uk-UA'=> 'Ukraynaca',
        'vi-VN'=> 'Vietnamca',
        'cy-GB'=> 'Galce',
        'zu-ZA'=> 'Zuluca',
    ],

    'select_country' => 'Ülke seçin',
    
    'countries' => [
        'AC'=>'Ascension Adası',
        'AD'=>'Andorra',
        'AE'=>'Birleşik Arap Emirlikleri',
        'AF'=>'Afganistan',
        'AG'=>'Antigua ve Barbuda',
        'AI'=>'Anguilla',
        'AL'=>'Arnavutluk',
        'AM'=>'Ermenistan',
        'AN'=>'Hollanda Antilleri',
        'AO'=>'Angola',
        'AQ'=>'Antarktika',
        'AR'=>'Arjantin',
        'AS'=>'Amerikan Samoası',
        'AT'=>'Avusturya',
        'AU'=>'Avustralya',
        'AW'=>'Aruba',
        'AX'=>'Aland',
        'AZ'=>'Azerbaycan',
        'BA'=>'Bosna Hersek',
        'BB'=>'Barbados',
        'BE'=>'Belçika',
        'BD'=>'Bangladeş',
        'BF'=>'Burkina Faso',
        'BG'=>'Bulgaristan',
        'BH'=>'Bahreyn',
        'BI'=>'Burundi',
        'BJ'=>'Benin',
        'BM'=>'Bermuda',
        'BN'=>'Brunei Sultanlığı',
        'BO'=>'Bolivya',
        'BR'=>'Brezilya',
        'BS'=>'Bahamalar',
        'BT'=>'Bhutan',
        'BV'=>'Bouvet Adası',
        'BW'=>'Botsvana',
        'BY'=>'Belarus',
        'BZ'=>'Belize',
        'CA'=>'Kanada',
        'CC'=>'Cocos (Keeling) Adaları',
        'CD'=>'Kongo Demokratik Cumhuriyeti',
        'CF'=>'Orta Afrika Cumhuriyeti',
        'CG'=>'Kongo Cunhuriyeti',
        'CH'=>'İsviçre',
        'CI'=>'Fildişi Sahili',
        'CK'=>'Cook Adaları',
        'CL'=>'Şili',
        'CM'=>'Kamerun',
        'CN'=>'Çin',
        'CO'=>'Kolombiya',
        'CR'=>'Kosta Rika',
        'CU'=>'Küba',
        'CV'=>'Cape Verde',
        'CX'=>'Christmas Adası',
        'CY'=>'Kıbrıs',
        'CZ'=>'Çek Cumhuriyeti',
        'DE'=>'Almanya',
        'DJ'=>'Cibuti',
        'DK'=>'Danimarka',
        'DM'=>'Dominik',
        'DO'=>'Dominik Cumhuriyeti',
        'DZ'=>'Cezayir',
        'EC'=>'Ekvador',
        'EE'=>'Estonya',
        'EG'=>'Mısır',
        'ER'=>'Eritre',
        'ES'=>'İspanya',
        'ET'=>'Etiyopya',
        'EU'=>'Avrupa Birliği',
        'FI'=>'Finlandiya',
        'FJ'=>'Fiji',
        'FK'=>'Falkland Adaları (Malvinalar)',
        'FM'=>'Mikronezya Federal Devletleri',
        'FO'=>'Faroe Adaları',
        'FR'=>'Fransa',
        'GA'=>'Gabon',
        'GD'=>'Grenada',
        'GE'=>'Gürcistan',
        'GF'=>'Fransız Guyanası',
        'GG'=>'Guernsey',
        'GH'=>'Gana',
        'GI'=>'Cebelitarık',
        'GL'=>'Grönland',
        'GM'=>'Gambiya',
        'GN'=>'Gine',
        'GP'=>'Guadeloup',
        'GQ'=>'Ekvator Ginesi',
        'GR'=>'Yunanistan',
        'GS'=>'Güney Georgia ve Güney Sandviç Adaları',
        'GT'=>'Guatemala',
        'GU'=>'Guam',
        'GW'=>'Gine-Bissau',
        'GY'=>'Guyana',
        'HK'=>'Hong Kong',
        'HM'=>'Heard ve Mc Donald Adaları',
        'HN'=>'Honduras',
        'HR'=>'Hırvatistan (yerel adı: Hrvatska)',
        'HT'=>'Haiti',
        'HU'=>'Macaristan',
        'ID'=>'Endonezya',
        'IE'=>'İrlanda',
        'IL'=>'İsrail',
        'IM'=>'Man Adası',
        'IN'=>'Hindistan',
        'IO'=>'İngiliz Hint Okyanusu Bölgesi',
        'IQ'=>'Irak',
        'IR'=>'İran İslam Cumhuriyeti',
        'IS'=>'İzlanda',
        'IT'=>'İtalya',
        'JE'=>'Jersey',
        'JM'=>'Jamaika',
        'JO'=>'Ürdün',
        'JP'=>'Japonya',
        'KE'=>'Kenya',
        'KG'=>'Kırgızistan',
        'KH'=>'Kamboçya',
        'KI'=>'Kiribati',
        'KM'=>'Komor Adaları',
        'KN'=>'Saint Kitts ve Nevis',
        'KR'=>'Kore Cumhuriyeti',
        'KW'=>'Kuveyt',
        'KY'=>'Cayman Adaları',
        'KZ'=>'Kazakistan',
        'LA'=>'Lao Demokratik Halk Cumhuriyeti',
        'LB'=>'Lübnan',
        'LC'=>'Saint Lucia',
        'LI'=>'Lihtenştayn',
        'LK'=>'Sri Lanka',
        'LR'=>'Liberya',
        'LS'=>'Lesoto',
        'LT'=>'Litvanya',
        'LU'=>'Lüksemburg',
        'LV'=>'Letonya',
        'LY'=>'Libya Arap Cemahiriyesi',
        'MA'=>'Fas',
        'MC'=>'Monako',
        'MD'=>'Moldova Cumhuriyeti',
        'ME'=>'Karadağ',
        'MG'=>'Madagaskar',
        'MH'=>'Marshall Adaları',
        'MK'=>'Makedonya, Eski Yugoslav Cumhuriyeti',
        'ML'=>'Mali',
        'MM'=>'Myanmar',
        'MN'=>'Moğolistan',
        'MO'=>'Makao',
        'MP'=>'Kuzey Mariana Adaları',
        'MQ'=>'Martinik',
        'MR'=>'Moritanya',
        'MS'=>'Montserrat',
        'MT'=>'Malta',
        'MU'=>'Mauritius',
        'MV'=>'Maldivler',
        'MW'=>'Malavi',
        'MX'=>'Meksika',
        'MY'=>'Malezya',
        'MZ'=>'Mozambik',
        'NA'=>'Namibya',
        'NC'=>'Yeni Kaledonya',
        'NE'=>'Nijer',
        'NF'=>'Norfolk Adası',
        'NG'=>'Nijerya',
        'NI'=>'Nikaragua',
        'NL'=>'Hollanda',
        'NO'=>'Norveç',
        'NP'=>'Nepal',
        'NR'=>'Nauru',
        'NU'=>'Niue',
        'NZ'=>'Yeni Zelanda',
        'OM'=>'Umman',
        'PA'=>'Panama',
        'PE'=>'Peru',
        'PF'=>'Fransız Polinezyası',
        'PG'=>'Papua Yeni Gine',
        'PH'=>'Filipin Cumhuriyeti',
        'PK'=>'Pakistan',
        'PL'=>'Polonya',
        'PM'=>'Saint Pierre ve Miquelon',
        'PN'=>'Pitcairn',
        'PR'=>'Porto Riko',
        'PS'=>'Filistin',
        'PT'=>'Portekiz',
        'PW'=>'Palau',
        'PY'=>'Paraguay',
        'QA'=>'Katar',
        'RE'=>'Reunion adası',
        'RO'=>'Romanya',
        'RS'=>'Sırbistan',
        'RU'=>'Rusya Federasyonu',
        'RW'=>'Ruanda',
        'SA'=>'Suudi Arabistan',
        'UK'=>'İskoçya',
        'SB'=>'Solomon Adaları',
        'SC'=>'Seyşel Adaları',
        'SS'=>'Güney Sudan',
        'SD'=>'Sudan',
        'SE'=>'İsveç',
        'SG'=>'Singapur',
        'SH'=>'Saint Helena',
        'SI'=>'Slovenya',
        'SJ'=>'Svalbard ve Jan Mayen',
        'SK'=>'Slovakya (Slovak Cumhuriyeti)',
        'SL'=>'Sierra Leone',
        'SM'=>'San Marino',
        'SN'=>'Senegal',
        'SO'=>'Somali',
        'SR'=>'Surinam',
        'ST'=>'Sao Tome ve Principe',
        'SU'=>'Sovyetler Birliği',
        'SV'=>'El Salvador',
        'SY'=>'Suriye Arap Cumhuriyeti',
        'SZ'=>'Svaziland',
        'TC'=>'Turks ve Caicos Adaları',
        'TD'=>'Çad',
        'TF'=>'Fransız Güney Toprakları',
        'TG'=>'Togo',
        'TH'=>'Tayland',
        'TJ'=>'Tacikistan',
        'TK'=>'Tokelau',
        'TI'=>'Doğu Timor',
        'TM'=>'Türkmenistan',
        'TN'=>'Tunus',
        'TO'=>'Tonga',
        'TP'=>'Doğu Timor (eski kod)',
        'TR'=>'Türkiye',
        'TT'=>'Trinidad ve Tobago',
        'TV'=>'Tuvalu',
        'TW'=>'Tayvan',
        'TZ'=>'Birleşik Tanzaya Cumhuriyeti',
        'UA'=>'Ukrayna',
        'UG'=>'Uganda',
        'UK'=>'Birleşik Krallık',
        'US'=>'Amerika Birleşik Devletleri',
        'UM'=>'Amerika Birleşik Devletleri Küçük Dış Adaları',
        'UY'=>'Uruguay',
        'UZ'=>'Özbekistan',
        'VA'=>'Vatikan Şehir Devleti (Vatikan)',
        'VC'=>'Saint Vincent ve Grenadinler',
        'VE'=>'Venezuela',
        'VG'=>'Virgin Adaları (Britanya)',
        'VI'=>'Virgin Adaları (Abd)',
        'VN'=>'Vietnam',
        'VU'=>'Vanuatu',
        'WF'=>'Wallis ve Futuna Adaları',
        'WS'=>'Samoa',
        'YE'=>'Yemen',
        'YT'=>'Mayotte',
        'ZA'=>'Güney Afrika',
        'ZM'=>'Zambiya',
        'ZW'=>'Zimbabve',
    ],
];
